pub struct PetFacetPowerQ {
pub facet: PetFacet,
pub q_first_level: f64,
pub q_max_level: f64,
}Expand description
One facet’s approximate contribution to displayed Power (BAL-030), authored as the value ON A ROLL: the die is folded into the estimator separately, so this number is what the facet is worth in the phase it comes up in.
Fields
facet: PetFacetq_first_level: f64q_max_level: f64Trait Implementations
Sourceimpl Clone for PetFacetPowerQ
impl Clone for PetFacetPowerQ
Sourcefn clone(&self) -> PetFacetPowerQ
fn clone(&self) -> PetFacetPowerQ
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PetFacetPowerQ
impl Debug for PetFacetPowerQ
Sourceimpl<'de> Deserialize<'de> for PetFacetPowerQ
impl<'de> Deserialize<'de> for PetFacetPowerQ
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for PetFacetPowerQ
impl JsonSchema for PetFacetPowerQ
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
fn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl Serialize for PetFacetPowerQ
impl Serialize for PetFacetPowerQ
Sourceimpl Tsify for PetFacetPowerQ
impl Tsify for PetFacetPowerQ
const DECL: &'static str = "/**\n * One facet\\\'s approximate contribution to displayed Power (BAL-030), authored\n * as the value ON A ROLL: the die is folded into the estimator separately, so\n * this number is what the facet is worth in the phase it comes up in.\n */\nexport interface PetFacetPowerQ {\n facet: PetFacet;\n q_first_level: number;\n q_max_level: number;\n}"
const SERIALIZATION_CONFIG: SerializationConfig
type JsType = JsType
fn into_js(&self) -> Result<Self::JsType, Error>where
Self: Serialize,
fn from_js<T>(js: T) -> Result<Self, Error>
impl Copy for PetFacetPowerQ